
function get_zenang,item, lat, lon, altitude, $
		     radians=radians, angle=angle, qstop=qstop
;+
;   Name: get_zenang
;
;   Purpose: return solar Zenith angle (see ssw_pos2zenith wrapper)
;
;   Input Parameters:
;      item - something containing a UT time, any SSW format
;      lat,lon - lattitude and longitude in degrees
;      altitude - KM above sea level - insignificant for low earth (default=zero)
;
;   Output:
;      function returns solar zenith angle - degrees is default
;
;   Keyword Parameters:
;      radians - if set, function returns angle in radians
;      degrees - if set, function returns angle in degrees (default)    
;  
;        
; inputs
;   lat   - latitude (assumed to be in deg for now)
;   lon   - lon (assumed to be in deg for now)
; output
;   zenith angle (in rad by def - set /ang for deg)
; optional keyword
;   angle - if set, output is deg, otherwise rad
;   History:
;      16-March-2000 - G.L.Slater, LMSAL
;      16-March-2000 - S.L.Freeland, LMSAL some doc, made ANGLE default  
;
;-  
d2rad = !dpi/180.d0		; deg to rad conv
h2rad = !dpi/12.d0		; RA to rad conv

jd = tim2jd(item)		; Julian date
ct2lst, lst, lon, dummy, jd	; Get sidereal time

; Compute RA and Dec:
ra_zen = lst * h2rad
dec_zen = ra_zen*0. + lat*d2rad

sunpos,jd,ra_sun,dec_sun,/rad

th1 = !pi/2 - dec_zen
th2 = !pi/2 - dec_sun
ph1 = ra_zen
ph2 = ra_sun

sth1 = sin(th1)
cth1 = cos(th1)
sph1 = sin(ph1)
cph1 = cos(ph1)

sth2 = sin(th2)
cth2 = cos(th2)
sph2 = sin(ph2)
cph2 = cos(ph2)

x1 = sth1*cph1
y1 = sth1*sph1
z1 = cth1

x2 = sth2*cph2
y2 = sth2*sph2
z2 = cth2

zenang = acos(x1*x2 + y1*y2 + z1*z2)
if not keyword_set(radians) then zenang = zenang*!radeg ; def=degrees

if exist(qstop) then stop
return, zenang

end
